export declare enum SortEnum {
    ASC = 0,
    DESC = 1
}
export declare enum FilterVisibility {
    Visible = "Visible",
    Hidden = "Hidden"
}
export declare enum OrderStage {
    Quotation = "Quotation",
    QuotationSent = "QuotationSent",
    SalesOrder = "SalesOrder",
    Locked = "Locked",
    Cancelled = "Cancelled"
}
export declare type Currency = {
    id: number;
    name?: string;
    symbol?: string;
};
export declare type Address = Partner;
export declare type DeliveryMethod = {
    id: number;
    name: string;
    price: number;
};
export declare type PaymentIcon = {
    id: number;
    name: string;
    image: string;
};
export declare type ShippingInfo = Record<string, string>;
export declare type PaymentProvider = {
    id: number;
    name: string;
    component: string;
    paymentIcons?: PaymentIcon[];
};
export declare type PaymentMethod = {
    name: string;
};
export declare type AttributeValue = {
    id: number;
    name: string;
    displayType: string;
    htmlColor?: string;
    search: string;
    priceExtra?: number;
    attribute?: Attribute;
};
export declare type Attribute = {
    id: number;
    name?: string;
    displayType?: string;
    filterVisibility?: FilterVisibility;
    values?: AttributeValue[];
};
export declare type Category = {
    id: number;
    name: string;
    slug: string;
    parent?: Category;
    childs?: Category[];
    products?: Product[];
};
export declare type CategoryFilterInput = {
    id: number;
    parent: boolean;
};
export declare type OrderSortInput = {
    id: SortEnum;
    dateOrder: SortEnum;
    name: SortEnum;
    state: SortEnum;
};
export declare type ProductFilterInput = {
    categoryId?: number[];
    attributeValueId?: number[];
    attribValues?: string[];
    minPrice?: number;
    maxPrice?: number;
};
export declare type CategorySortInput = {
    id: SortEnum;
};
export declare type PaymentForm = {
    form: string;
};
export declare type ProductSortInput = {
    id?: SortEnum;
    price?: SortEnum;
};
export declare type GraphQlGetCategoryParams = {
    filter: CategoryFilterInput;
    currentPage?: number;
    pageSize?: number;
    search?: string;
    sort?: CategorySortInput;
};
export declare type CartRemoveItemResult = {
    cartRemoveItem: Cart;
};
export declare type BillingGetAddressResult = {
    addresses: Partner[];
};
export declare type GraphQlDeleteAddressParams = {
    id: number;
};
export declare type PaymentLoadProvidersResult = {
    paymentAcquirers: PaymentProvider[];
};
export declare type CountryStatesResult = {
    country: Country;
};
export declare type Countries = {
    countries: Country[];
};
export declare type CountriesResult = {
    countries: Countries;
};
export declare type PaymentMakeExternalResult = {
    makePayment: PaymentForm;
};
export declare type Orders = {
    orders: Order[];
};
export declare type OrdersResponse = {
    orders: Orders;
};
export declare type ShippingUpdateAddressResponse = {
    updateAddress: Partner;
};
export declare type WishlistLoadResponse = {
    wishlistItems: Wishlist;
};
export declare type WishlistAddItemResponse = {
    wishlistAddItem: Wishlist;
};
export declare type WishlistRemoveItemResponse = {
    wishlistRemoveItem: Wishlist;
};
export declare type ShippingAddAddresResponse = {
    addAddress: Partner;
};
export declare type BillingAddAddresResponse = {
    addAddress: Partner;
};
export declare type CartUpdateItemQtyResponse = {
    cartUpdateItem: Cart;
};
export declare type ProductResult = {
    products: Products;
};
export declare type CartAddItemResult = {
    cartAddItem: Cart;
};
export declare type cartAddMultipleItemsResult = {
    cartAddMultipleItems: Cart;
};
export declare type cartRemoveMultipleItemsResult = {
    cartRemoveMultipleItems: Cart;
};
export declare type CartLoadResult = {
    cart: Cart;
};
export declare type LoadUserResult = {
    partner: Partner;
};
export declare type LoginResult = {
    login: LoadUserResult;
};
export declare type RegisterResult = {
    register: Partner;
};
export declare type BillingUpdateAddressResult = {
    updateAddress: Partner;
};
export declare type UpdateAccountResult = {
    updateMyAccount: Partner;
};
export declare type ProductVariantResult = {
    productVariant: ProductVariant;
};
export declare type SingleProductResult = {
    product: Product;
};
export declare type Products = {
    products: Product[];
    totalCount: number;
    attributeValues: AttributeValue[];
};
export declare type Categories = {
    categories: Category[];
    totalCount: number;
};
export declare type CategoryResult = {
    categories: Categories;
};
export declare type ShippingGetDeliveryMethodsResult = {
    deliveryMethods: DeliveryMethod[];
};
export declare type ShippingGetAddresessResult = {
    addresses: Partner[];
};
export declare type ProductImage = {
    id: number;
    name: string;
    image: string;
    video: string;
};
export declare type Product = {
    id: number;
    description?: string;
    name?: string;
    displayName?: string;
    slug?: string;
    isInStock?: boolean;
    qty?: number;
    sku?: string;
    image?: string;
    variantImage?: string;
    smallImage?: string;
    mediaGallery?: ProductImage[];
    price?: number;
    weight?: number;
    priceAfterDiscount?: number;
    hasDiscountedPrice?: number;
    listPrice?: number;
    realProduct?: ProductVariant;
    firstVariant?: number;
    currency?: Currency;
    isInWishlist?: boolean;
    alternativeProducts?: Product[];
    accessoryProducts?: Product[];
    attributeValues?: AttributeValue[];
    productTemplate?: Product;
    categories?: Category[];
};
export declare type WishlistItem = {
    product: Product;
    variant: Product;
    id: number;
};
export declare type Wishlist = {
    wishlistItems?: WishlistItem[];
};
export interface AgnosticFacet {
    type: string;
    id?: string;
    label: string;
    value: any;
    attrName?: string;
    count?: number;
    selected?: boolean;
    metadata?: any;
}
export declare type State = {
    id: number;
    name?: string;
};
export declare type ShippingMethod = {
    id: number;
    name: string;
    price: number;
};
export declare type Country = {
    id: number;
    code?: string;
    name?: string;
    states?: State[];
};
export declare type AgnosticUser = {
    password: string;
    email: string;
    name: string;
    is_admin: boolean;
    uid: number;
    username: string;
    street?: string;
    street2?: string;
    city?: string;
    state?: State;
    zip?: string;
    country?: Country;
    phone?: string;
};
export declare type Partner = {
    id?: number;
    name: string;
    street: string;
    street2?: string;
    city: string;
    state: State;
    zip: string;
    country: Country;
    email?: string;
    phone: string;
    isCompany?: boolean;
    isDefault?: boolean;
    contacts?: Partner[];
    password?: string;
};
export declare type ProductVariant = {
    product: Product;
    productTemplateId: number;
    displayName: string;
    displayImage: boolean;
    price: number;
    listPrice: string;
    hasDiscountedPrice: boolean;
    isCombinationPossible: boolean;
};
export declare type OrderLine = {
    id: number;
    name?: string;
    product?: Product;
    quantity?: number;
    priceTotal?: number;
    priceUnit?: number;
    priceSubtotal?: number;
    priceTax?: number;
};
export declare type Payment = {
    id: number;
    name: string;
    provider: string;
    amount: number;
    paymentReference: string;
};
export declare type PaymentTransaction = {
    id: number;
    payment: Payment;
    paymentToken: string;
    amount: number;
    acquirer: string;
};
export declare type Order = {
    id: number;
    name: string;
    partner?: Partner;
    partnerShipping?: Partner;
    partnerInvoice?: Partner;
    dateOrder?: Date;
    amountUntaxed: number;
    amountTax: number;
    amountTotal: number;
    amountDelivery: number;
    currency: Currency;
    orderLines?: OrderLine[];
    websiteOrderLine?: OrderLine[];
    stage: OrderStage;
    orderUrl: string;
    transactions: PaymentTransaction[];
};
export declare type Cart = {
    order: Order;
};
export declare type Pagination = {
    limit?: number;
    offset?: number;
    sort?: string;
};
export declare type CategoryFilter = Record<string, unknown>;
export declare type LineItem = Record<string, unknown>;
export declare type Store = Record<string, any>;
export declare type DefaultGraphQlMutationResponse = {
    ok: boolean;
};
export declare type GraphQlSendResetPasswordParams = {
    email: string;
};
export declare type GraphQlGetProductVariants = {
    productId: number;
};
export declare type GraphQlCartRemoveItemParams = {
    lineId: number;
};
export declare type GraphQlWishlistAddItemParams = {
    productId: number;
};
export declare type GraphQlGetProductTemplateParams = {
    id: number;
};
export declare type GraphQlWishlistRemoveItemParams = {
    wishId: number;
};
export declare type GraphQlGetProductVariantParams = {
    productTemplateId: number;
    combinationId: string[];
};
export declare type GraphQlCartAddItemParams = {
    productId: number;
    quantity: number;
};
export declare type GraphQlAddAddressParams = {
    name: string;
    street: string;
    street2?: string;
    zip: string;
    city: string;
    stateId: number;
    countryId: number;
    phone: string;
    email?: string;
};
export declare type GraphQlUpdateAddressParams = {
    id: number;
    name: string;
    street: string;
    street2?: string;
    zip: string;
    city: string;
    stateId: number;
    countryId: number;
    phone: string;
    email?: string;
};
export declare type GraphQlCartUpdateItemQtyParams = {
    lineId: number;
    quantity: number;
};
export declare type GraphQlGetPricinsShippingMethodParams = {
    shippingId: string;
};
export declare type GraphQlResetPasswordParams = {
    newPassword: string;
    token: string;
};
export declare type CountryFiltersInput = {
    id: number;
};
export declare type GraphQlMakePaymentParams = {
    paymentAcquireId: number;
};
export declare type GraphQlOrdersParams = {
    currentPage: number;
    pageSize: number;
    sort: OrderSortInput;
    [x: string]: any;
};
export declare type GraphQlGetCountryParams = {
    id: number;
};
export declare type GraphQlLoginParams = {
    email: string;
    password: string;
};
export declare type GraphQlUpdateAccountParams = {
    id: number;
    name?: string;
    email?: string;
};
export declare type GraphQlGetProductParams = {
    filter?: ProductFilterInput;
    currentPage: number;
    pageSize: number;
    search?: string;
    sort: ProductSortInput;
};
export declare type GraphQlAddMultipleProductsParams = {
    products: GraphQlProductParam[];
};
export declare type GraphQlRemoveMultipleProductsParams = {
    lineIds: number[];
};
export declare type GraphQlProductParam = {
    id: number;
    quantity: number;
};
export declare type ParamsFromUrlFilterInput = {
    categoryId?: number;
    attributeValueId: number[];
    minPrice: string;
    maxPrice: string;
};
export declare type ParamsFromUrl = {
    filter: ParamsFromUrlFilterInput;
    currentPage: number;
    pageSize: number;
    search: string;
    categorySlug?: string;
    sort: ProductSortInput;
    customQueryProducts: any;
    customQueryCategories: any;
};
export interface AgnosticFacetSearchParams {
    categorySlug?: string;
    rootCatSlug?: string;
    term?: string;
    page?: number;
    itemsPerPage?: number;
    sort?: string | string[];
    filters?: Record<string, string[]>;
    metadata?: any;
    fetchCategory?: boolean;
    [x: string]: any;
}
export interface SearchResultParams<S> {
    data?: S;
    input: AgnosticFacetSearchParams;
}
//# sourceMappingURL=types.d.ts.map